Derivable

com.phasmidsoftware.args.Derivable
See theDerivable companion trait
object Derivable

Provides default given instances of the Derivable type class for specific types. Each instance defines a mechanism to derive a value of type T from an input value of type X.

Contains given instances for the following derivations:

  • Boolean from String
  • Int from String
  • Double from String
  • java.io.File from String
  • java.net.URL from String

Attributes

Companion
trait
Graph
Supertypes
class Object
trait Matchable
class Any
Self type
Derivable.type

Members list

Type members

Classlikes

object DerivableStringBoolean extends Derivable[Boolean]

Attributes

Supertypes
trait Derivable[Boolean]
class Object
trait Matchable
class Any
Self type
object DerivableStringDouble extends Derivable[Double]

Attributes

Supertypes
trait Derivable[Double]
class Object
trait Matchable
class Any
Self type
object DerivableStringFile extends Derivable[File]

Attributes

Supertypes
trait Derivable[File]
class Object
trait Matchable
class Any
Self type
object DerivableStringInt extends Derivable[Int]

Attributes

Supertypes
trait Derivable[Int]
class Object
trait Matchable
class Any
Self type
object DerivableStringURL extends Derivable[URL]

Attributes

Supertypes
trait Derivable[URL]
class Object
trait Matchable
class Any
Self type