Element

com.phasmidsoftware.args.Element
trait Element extends Ordered[Element]

This represents an element in the synopsis for a command line

Attributes

Graph
Supertypes
trait Ordered[Element]
trait Comparable[Element]
class Object
trait Matchable
class Any
Known subtypes
class Flag
class Operand
class Value

Members list

Value members

Abstract methods

def value: String

Method to yield the value (name) of this Element

Method to yield the value (name) of this Element

Attributes

Returns

the value/name

Concrete methods

def asOperand: Option[String]

Method to yield an optional String according as whether this Element is an operand.

Method to yield an optional String according as whether this Element is an operand.

Attributes

Returns

optionally the value of this Operand element (includes optional elements); None if this Element is not an operand.

def compare(that: Element): Int

Method to compare this Element with that Element.

Method to compare this Element with that Element.

Value parameters

that

the comparand.

Attributes

Returns

the result of invoking value compare that.value

def isOptional: Boolean

Method to determine if this Element is optional.

Method to determine if this Element is optional.

Attributes

Returns

true if this Element is optional.

Inherited methods

def <(that: Element): Boolean

Attributes

Inherited from:
Ordered
def <=(that: Element): Boolean

Attributes

Inherited from:
Ordered
def >(that: Element): Boolean

Attributes

Inherited from:
Ordered
def >=(that: Element): Boolean

Attributes

Inherited from:
Ordered
def compareTo(that: Element): Int

Attributes

Inherited from:
Ordered