Flag

com.phasmidsoftware.args.Flag
case class Flag(value: String) extends Element

This represents an "Option" in the parlance of POSIX command line interpretation (but formerly these options were known as flags)

Value parameters

value

the (single-character) String representing the option (flag)

Attributes

Graph
Supertypes
trait Serializable
trait Product
trait Equals
trait Element
trait Ordered[Element]
trait Comparable[Element]
class Object
trait Matchable
class Any
Show all

Members list

Value members

Inherited methods

def <(that: Element): Boolean

Attributes

Inherited from:
Ordered
def <=(that: Element): Boolean

Attributes

Inherited from:
Ordered
def >(that: Element): Boolean

Attributes

Inherited from:
Ordered
def >=(that: Element): Boolean

Attributes

Inherited from:
Ordered
def asOperand: Option[String]

Method to yield an optional String according as whether this Element is an operand.

Method to yield an optional String according as whether this Element is an operand.

Attributes

Returns

optionally the value of this Operand element (includes optional elements); None if this Element is not an operand.

Inherited from:
Element
def compare(that: Element): Int

Method to compare this Element with that Element.

Method to compare this Element with that Element.

Value parameters

that

the comparand.

Attributes

Returns

the result of invoking value compare that.value

Inherited from:
Element
def compareTo(that: Element): Int

Attributes

Inherited from:
Ordered
def isOptional: Boolean

Method to determine if this Element is optional.

Method to determine if this Element is optional.

Attributes

Returns

true if this Element is optional.

Inherited from:
Element
def productElementNames: Iterator[String]

Attributes

Inherited from:
Product
def productIterator: Iterator[Any]

Attributes

Inherited from:
Product