FlagWithValue

com.phasmidsoftware.args.FlagWithValue
case class FlagWithValue(value: String, element: Element) extends Element

This represents an "Option" and its "Value"

Value parameters

element

the Element which corresponds to the "value" of this synopsis flag (and which may of course be OptionalElement).

value

the flag or "option" String

Attributes

Graph
Supertypes
trait Serializable
trait Product
trait Equals
trait Element
trait Ordered[Element]
trait Comparable[Element]
class Object
trait Matchable
class Any
Show all

Members list

Value members

Concrete methods

override def equals(obj: Any): Boolean

Compares the receiver object (this) with the argument object (that) for equivalence.

Compares the receiver object (this) with the argument object (that) for equivalence.

Any implementation of this method should be an equivalence relation:

  • It is reflexive: for any instance x of type Any, x.equals(x) should return true.
  • It is symmetric: for any instances x and y of type Any, x.equals(y) should return true if and only if y.equals(x) returns true.
  • It is transitive: for any instances x, y, and z of type Any if x.equals(y) returns true and y.equals(z) returns true, then x.equals(z) should return true.

If you override this method, you should verify that your implementation remains an equivalence relation. Additionally, when overriding this method it is usually necessary to override hashCode to ensure that objects which are "equal" (o1.equals(o2) returns true) hash to the same scala.Int. (o1.hashCode.equals(o2.hashCode)).

Value parameters

that

the object to compare against this object for equality.

Attributes

Returns

true if the receiver object is equivalent to the argument; false otherwise.

Definition Classes
Equals -> Any
override def hashCode(): Int

Calculates a hash code value for the object.

Calculates a hash code value for the object.

The default hashing algorithm is platform dependent.

Note that it is allowed for two objects to have identical hash codes (o1.hashCode.equals(o2.hashCode)) yet not be equal (o1.equals(o2) returns false). A degenerate implementation could always return 0. However, it is required that if two objects are equal (o1.equals(o2) returns true) that they have identical hash codes (o1.hashCode.equals(o2.hashCode)). Therefore, when overriding this method, be sure to verify that the behavior is consistent with the equals method.

Attributes

Returns

the hash code value for this object.

Definition Classes
Any

Inherited methods

def <(that: Element): Boolean

Attributes

Inherited from:
Ordered
def <=(that: Element): Boolean

Attributes

Inherited from:
Ordered
def >(that: Element): Boolean

Attributes

Inherited from:
Ordered
def >=(that: Element): Boolean

Attributes

Inherited from:
Ordered
def asOperand: Option[String]

Method to yield an optional String according as whether this Element is an operand.

Method to yield an optional String according as whether this Element is an operand.

Attributes

Returns

optionally the value of this Operand element (includes optional elements); None if this Element is not an operand.

Inherited from:
Element
def compare(that: Element): Int

Method to compare this Element with that Element.

Method to compare this Element with that Element.

Value parameters

that

the comparand.

Attributes

Returns

the result of invoking value compare that.value

Inherited from:
Element
def compareTo(that: Element): Int

Attributes

Inherited from:
Ordered
def isOptional: Boolean

Method to determine if this Element is optional.

Method to determine if this Element is optional.

Attributes

Returns

true if this Element is optional.

Inherited from:
Element
def productElementNames: Iterator[String]

Attributes

Inherited from:
Product
def productIterator: Iterator[Any]

Attributes

Inherited from:
Product