Synopsis

com.phasmidsoftware.args.Synopsis
case class Synopsis(es: Seq[Element])

Represents a synopsis for a command line, containing a sequence of elements.

Value parameters

es

the sequence of elements in the synopsis

Attributes

Graph
Supertypes
trait Serializable
trait Product
trait Equals
class Object
trait Matchable
class Any
Show all

Members list

Value members

Concrete methods

def find(wo: Option[String]): Option[Element]

Method to find an element by its value (basically that's its name)

Method to find an element by its value (basically that's its name)

Value parameters

wo

an optional value string

Attributes

Returns

an Option[Element]

def getElement(value: String): Option[Element]

Method to get an element by value (basically that's its name).

Method to get an element by value (basically that's its name).

TEST this method

Value parameters

value

the value to find

Attributes

Returns

an Option[Element]

Method to distinguish between mandatory and optional elements.

Method to distinguish between mandatory and optional elements.

Attributes

Returns

a tuple of Element sequences--first is the mandatory elements, second is the optional elements.

def operandArity: (Int, Int)

Method to get the arity of the operands declared by this synopsis.

Method to get the arity of the operands declared by this synopsis.

Attributes

Returns

a tuple of (minimum, maximum) operand count: the minimum is the number of mandatory (unwrapped) Operand elements; the maximum is the total number of operand elements, mandatory and optional.

def operands: Seq[String]

Method to get the operands (the non-option parameters) as a sequence of Strings

Method to get the operands (the non-option parameters) as a sequence of Strings

Attributes

Returns

Seq[String]

Inherited methods

def productElementNames: Iterator[String]

Attributes

Inherited from:
Product
def productIterator: Iterator[Any]

Attributes

Inherited from:
Product