com.phasmidsoftware.examples

Members list

Type members

Classlikes

object ExampleInt

In this example, we convert all of the arguments into Ints.

In this example, we convert all of the arguments into Ints.

Attributes

Supertypes
class Object
trait Matchable
class Any
Self type
ExampleInt.type