com.phasmidsoftware.util

Members list

Type members

Classlikes

object Kleenean

Companion object to Kleenean

Companion object to Kleenean

Attributes

Companion
class
Supertypes
trait Product
trait Mirror
class Object
trait Matchable
class Any
Self type
Kleenean.type
case class Kleenean(value: Option[Boolean]) extends Maybe

This is the Kleenean case class which extends Maybe

This is the Kleenean case class which extends Maybe

Value parameters

value

the Option[Boolean] value

Attributes

Companion
object
Supertypes
trait Serializable
trait Product
trait Equals
trait Maybe
trait () => Option[Boolean]
class Object
trait Matchable
class Any
Show all
Known subtypes
object ^^
trait Maybe extends () => Option[Boolean]

This trait is to support Kleenean algebra, potentially in a disjunctive or conjunctive expression. The truth-tables for Kleenean logic can be found here: See https://en.wikipedia.org/wiki/Three-valued_logic#Logics Or you can look at KleeneanSpec to see what the rules are.

This trait is to support Kleenean algebra, potentially in a disjunctive or conjunctive expression. The truth-tables for Kleenean logic can be found here: See https://en.wikipedia.org/wiki/Three-valued_logic#Logics Or you can look at KleeneanSpec to see what the rules are.

The original source and specification for Kleenean is in the LaScala project on github at https://github.com/rchillyard/LaScala

Attributes

Companion
object
Supertypes
trait () => Option[Boolean]
class Object
trait Matchable
class Any
Known subtypes
class Kleenean
object ^^
object Maybe

Companion object to Maybe

Companion object to Maybe

Attributes

Companion
trait
Supertypes
class Object
trait Matchable
class Any
Self type
Maybe.type
object MonadOps

Attributes

Supertypes
class Object
trait Matchable
class Any
Self type
MonadOps.type
object ^^ extends Kleenean

This case object is the None version of Maybe. It is used for the bookends of a dis/conjunctive expression of Maybes. But be careful, you need to understand the rules of Kleenean logic with regard to None combining with true or false.

This case object is the None version of Maybe. It is used for the bookends of a dis/conjunctive expression of Maybes. But be careful, you need to understand the rules of Kleenean logic with regard to None combining with true or false.

Attributes

Supertypes
class Kleenean
trait Serializable
trait Product
trait Equals
trait Maybe
trait () => Option[Boolean]
class Object
trait Matchable
class Any
Show all
Self type
^^.type