Kleenean

com.phasmidsoftware.util.Kleenean
See theKleenean companion object
case class Kleenean(value: Option[Boolean]) extends Maybe

This is the Kleenean case class which extends Maybe

Value parameters

value

the Option[Boolean] value

Attributes

Companion
object
Graph
Supertypes
trait Serializable
trait Product
trait Equals
trait Maybe
trait () => Option[Boolean]
class Object
trait Matchable
class Any
Show all
Known subtypes
object ^^

Members list

Value members

Concrete methods

def apply(): Option[Boolean]

Inherited methods

def &&:(x: Option[Boolean]): Kleenean

Right-associative conjunctive operator with an Option[Boolean]

Right-associative conjunctive operator with an Option[Boolean]

Value parameters

x

other Maybe value

Attributes

Returns

a Maybe value with is the Kleenean logical AND of this and x

Inherited from:
Maybe
def &:(b: Boolean): Kleenean

Right-associative conjunctive operator with a Boolean

Right-associative conjunctive operator with a Boolean

Value parameters

b

other Maybe value

Attributes

Returns

a Maybe value with is the Kleenean logical AND of this and b

Inherited from:
Maybe
def :&(b: Boolean): Kleenean

Left-associative conjunctive operator with a Boolean

Left-associative conjunctive operator with a Boolean

Value parameters

b

other Boolean value

Attributes

Returns

a Maybe value with is the Kleenean logical AND of this and b

Inherited from:
Maybe
def :&&(m: => Maybe): Kleenean

Left-associative conjunctive operator with another Maybe

Left-associative conjunctive operator with another Maybe

Value parameters

m

other Maybe value

Attributes

Returns

a Maybe value with is the Kleenean logical AND of this and m

Inherited from:
Maybe
def :|(b: Boolean): Kleenean

Left-associative disjunctive operator with a Boolean

Left-associative disjunctive operator with a Boolean

Value parameters

b

other Maybe value

Attributes

Returns

a Maybe value with is the Kleenean logical OR of this and b

Inherited from:
Maybe
def :||(m: => Maybe): Kleenean

Left-associative disjunctive operator with another Maybe

Left-associative disjunctive operator with another Maybe

Value parameters

m

other Maybe value

Attributes

Returns

a Maybe value with is the Kleenean logical OR of this and m

Inherited from:
Maybe
def deny: Kleenean

Method to deny (invert, negate, ...) this Maybe

Method to deny (invert, negate, ...) this Maybe

TEST this method

Attributes

Returns

Some(!x) if exists, else return None

Inherited from:
Maybe
def productElementNames: Iterator[String]

Attributes

Inherited from:
Product
def productIterator: Iterator[Any]

Attributes

Inherited from:
Product
def toBoolean(default: => Boolean): Boolean

Method to convert this Maybe into a Boolean

Method to convert this Maybe into a Boolean

Value parameters

default

the value to use if this is None

Attributes

Returns

a Boolean corresponding to either the existing Boolean or else the given default.

Inherited from:
Maybe
def toInt: Int

Method to convert this Maybe into an integer corresponding to the return value of compareTo

Method to convert this Maybe into an integer corresponding to the return value of compareTo

TEST this method

Attributes

Returns

either 1 (true), 0 (maybe), or -1 (false)

Inherited from:
Maybe
override def toString: String

Returns a string representation of the object.

Returns a string representation of the object.

The default representation is platform dependent.

Attributes

Returns

a string representation of the object.

Definition Classes
Maybe -> Function0 -> Any
Inherited from:
Maybe
def |:(b: Boolean): Kleenean

Right-associative disjunctive operator with a Boolean

Right-associative disjunctive operator with a Boolean

Value parameters

b

other Maybe value

Attributes

Returns

a Maybe value with is the Kleenean logical OR of this and b

Inherited from:
Maybe
def ||:(x: Option[Boolean]): Kleenean

Right-associative disjunctive operator with an Option[Boolean]

Right-associative disjunctive operator with an Option[Boolean]

Value parameters

x

other Maybe value

Attributes

Returns

a Maybe value with is the Kleenean logical OR of this and x

Inherited from:
Maybe