Maybe

com.phasmidsoftware.util.Maybe
See theMaybe companion object
trait Maybe extends () => Option[Boolean]

This trait is to support Kleenean algebra, potentially in a disjunctive or conjunctive expression. The truth-tables for Kleenean logic can be found here: See https://en.wikipedia.org/wiki/Three-valued_logic#Logics Or you can look at KleeneanSpec to see what the rules are.

The original source and specification for Kleenean is in the LaScala project on github at https://github.com/rchillyard/LaScala

Attributes

Companion
object
Graph
Supertypes
trait () => Option[Boolean]
class Object
trait Matchable
class Any
Known subtypes
class Kleenean
object ^^

Members list

Value members

Concrete methods

def &&:(x: Option[Boolean]): Kleenean

Right-associative conjunctive operator with an Option[Boolean]

Right-associative conjunctive operator with an Option[Boolean]

Value parameters

x

other Maybe value

Attributes

Returns

a Maybe value with is the Kleenean logical AND of this and x

def &:(b: Boolean): Kleenean

Right-associative conjunctive operator with a Boolean

Right-associative conjunctive operator with a Boolean

Value parameters

b

other Maybe value

Attributes

Returns

a Maybe value with is the Kleenean logical AND of this and b

def :&(b: Boolean): Kleenean

Left-associative conjunctive operator with a Boolean

Left-associative conjunctive operator with a Boolean

Value parameters

b

other Boolean value

Attributes

Returns

a Maybe value with is the Kleenean logical AND of this and b

def :&&(m: => Maybe): Kleenean

Left-associative conjunctive operator with another Maybe

Left-associative conjunctive operator with another Maybe

Value parameters

m

other Maybe value

Attributes

Returns

a Maybe value with is the Kleenean logical AND of this and m

def :|(b: Boolean): Kleenean

Left-associative disjunctive operator with a Boolean

Left-associative disjunctive operator with a Boolean

Value parameters

b

other Maybe value

Attributes

Returns

a Maybe value with is the Kleenean logical OR of this and b

def :||(m: => Maybe): Kleenean

Left-associative disjunctive operator with another Maybe

Left-associative disjunctive operator with another Maybe

Value parameters

m

other Maybe value

Attributes

Returns

a Maybe value with is the Kleenean logical OR of this and m

def deny: Kleenean

Method to deny (invert, negate, ...) this Maybe

Method to deny (invert, negate, ...) this Maybe

TEST this method

Attributes

Returns

Some(!x) if exists, else return None

def toBoolean(default: => Boolean): Boolean

Method to convert this Maybe into a Boolean

Method to convert this Maybe into a Boolean

Value parameters

default

the value to use if this is None

Attributes

Returns

a Boolean corresponding to either the existing Boolean or else the given default.

def toInt: Int

Method to convert this Maybe into an integer corresponding to the return value of compareTo

Method to convert this Maybe into an integer corresponding to the return value of compareTo

TEST this method

Attributes

Returns

either 1 (true), 0 (maybe), or -1 (false)

override def toString: String

Returns a string representation of the object.

Returns a string representation of the object.

The default representation is platform dependent.

Attributes

Returns

a string representation of the object.

Definition Classes
Function0 -> Any
def |:(b: Boolean): Kleenean

Right-associative disjunctive operator with a Boolean

Right-associative disjunctive operator with a Boolean

Value parameters

b

other Maybe value

Attributes

Returns

a Maybe value with is the Kleenean logical OR of this and b

def ||:(x: Option[Boolean]): Kleenean

Right-associative disjunctive operator with an Option[Boolean]

Right-associative disjunctive operator with an Option[Boolean]

Value parameters

x

other Maybe value

Attributes

Returns

a Maybe value with is the Kleenean logical OR of this and x

Inherited and Abstract methods

def apply(): Option[Boolean]

Attributes

Inherited from:
Function0