com.phasmidsoftware.args
Members list
Type members
Classlikes
Attributes
- Supertypes
-
trait Producttrait Equalsclass ArgsExceptionclass Exceptionclass Throwabletrait Serializableclass Objecttrait Matchableclass AnyShow all
Attributes
- Supertypes
-
trait Singletontrait Producttrait Mirrortrait Producttrait Equalsclass ArgsExceptionclass Exceptionclass Throwabletrait Serializableclass Objecttrait Matchableclass AnyShow all
- Self type
Case class to represent an "option" in a command line. Such an option has an (optional) name which is a String; and an (optional) value, which is of type X.
Case class to represent an "option" in a command line. Such an option has an (optional) name which is a String; and an (optional) value, which is of type X.
Type parameters
- X
-
the underlying type of the value.
Value parameters
- name
-
the optional name.
- value
-
the optional value.
Attributes
- Companion
- object
- Supertypes
Attributes
- Companion
- object
- Supertypes
-
trait Serializabletrait Producttrait Equalsclass Objecttrait Matchableclass AnyShow all
Attributes
- Supertypes
-
class Exceptionclass Throwabletrait Serializableclass Objecttrait Matchableclass AnyShow all
- Known subtypes
-
class AmbiguousNameExceptionobject AnonymousNotFoundExceptionobject EmptyArgsExceptionclass InvalidOptionException[X]class MapExceptionclass NoMatchExceptionclass NoValueExceptionclass NotFoundExceptionclass ParseExceptionclass ValidationException[X]Show all
Type-class trait to allow conversion from type X to type T
Type-class trait to allow conversion from type X to type T
Type parameters
- T
-
the result type
Attributes
- Companion
- object
- Supertypes
-
class Objecttrait Matchableclass Any
- Known subtypes
-
object DerivableStringBooleanobject DerivableStringDoubleobject DerivableStringFileobject DerivableStringIntobject DerivableStringURL
Provides default given instances of the Derivable type class for specific types. Each instance defines a mechanism to derive a value of type T from an input value of type X.
Provides default given instances of the Derivable type class for specific types. Each instance defines a mechanism to derive a value of type T from an input value of type X.
Contains given instances for the following derivations:
- Boolean from String
- Int from String
- Double from String
- java.io.File from String
- java.net.URL from String
Attributes
This represents an element in the synopsis for a command line
This represents an element in the synopsis for a command line
Attributes
- Supertypes
- Known subtypes
Attributes
- Supertypes
-
trait Singletontrait Producttrait Mirrortrait Producttrait Equalsclass ArgsExceptionclass Exceptionclass Throwabletrait Serializableclass Objecttrait Matchableclass AnyShow all
- Self type
-
EmptyArgsException.type
This represents an "Option" in the parlance of POSIX command line interpretation (but formerly these options were known as flags)
This represents an "Option" in the parlance of POSIX command line interpretation (but formerly these options were known as flags)
Value parameters
- value
-
the (single-character) String representing the option (flag)
Attributes
- Supertypes
This represents an "Option" and its "Value"
This represents an "Option" and its "Value"
Value parameters
- element
-
the Element which corresponds to the "value" of this synopsis flag (and which may of course be OptionalElement).
- value
-
the flag or "option" String
Attributes
- Supertypes
Attributes
- Supertypes
-
trait Producttrait Equalsclass ArgsExceptionclass Exceptionclass Throwabletrait Serializableclass Objecttrait Matchableclass AnyShow all
Attributes
- Supertypes
-
trait Producttrait Equalsclass ArgsExceptionclass Exceptionclass Throwabletrait Serializableclass Objecttrait Matchableclass AnyShow all
Attributes
- Supertypes
-
trait Producttrait Equalsclass RuntimeExceptionclass Exceptionclass Throwabletrait Serializableclass Objecttrait Matchableclass AnyShow all
Attributes
- Supertypes
-
trait Producttrait Equalsclass ArgsExceptionclass Exceptionclass Throwabletrait Serializableclass Objecttrait Matchableclass AnyShow all
Attributes
- Supertypes
-
trait Producttrait Equalsclass ArgsExceptionclass Exceptionclass Throwabletrait Serializableclass Objecttrait Matchableclass AnyShow all
Attributes
- Supertypes
-
trait Producttrait Equalsclass ArgsExceptionclass Exceptionclass Throwabletrait Serializableclass Objecttrait Matchableclass AnyShow all
Attributes
- Supertypes
-
trait Producttrait Equalsclass ArgsExceptionclass Exceptionclass Throwabletrait Serializableclass Objecttrait Matchableclass AnyShow all
This represents an operand in the parlance of POSIX.
This represents an optional synopsis element, either an optional flag, or an optional value.
This represents an optional synopsis element, either an optional flag, or an optional value.
Value parameters
- element
-
a synopsis element that is optional
Attributes
- Supertypes
Attributes
- Supertypes
-
trait Producttrait Equalsclass ArgsExceptionclass Exceptionclass Throwabletrait Serializableclass Objecttrait Matchableclass AnyShow all
Parser of POSIX-style command lines.
Parser of POSIX-style command lines.
TODO there is a problem with testing equality of Elements (it's too liberal)
Attributes
- Supertypes
-
trait RegexParserstrait Parsersclass Objecttrait Matchableclass Any
a Posix Arg
a Posix Arg
Attributes
- Supertypes
-
class Objecttrait Matchableclass Any
- Known subtypes
-
class PosixOperandclass PosixOptionString
The value of an operand, i.e. a String which follows all of the options and their values.
The value of an operand, i.e. a String which follows all of the options and their values.
Value parameters
- value
-
a String
Attributes
- Supertypes
-
trait Serializabletrait Producttrait Equalstrait PosixArgclass Objecttrait Matchableclass AnyShow all
One or more options. Each option is a single-letter, although the terminating characters can be a value.
One or more options. Each option is a single-letter, although the terminating characters can be a value.
Value parameters
- value
-
the string of options, without the "-" prefix.
Attributes
- Supertypes
-
trait Serializabletrait Producttrait Equalstrait PosixArgclass Objecttrait Matchableclass AnyShow all
Parser of non-POSIX command lines
Parser of non-POSIX command lines
Attributes
- Supertypes
-
trait RegexParserstrait Parsersclass Objecttrait Matchableclass Any
Represents a synopsis for a command line, containing a sequence of elements.
Represents a synopsis for a command line, containing a sequence of elements.
Value parameters
- es
-
the sequence of elements in the synopsis
Attributes
- Supertypes
-
trait Serializabletrait Producttrait Equalsclass Objecttrait Matchableclass AnyShow all
SynopsisParser is responsible for parsing a command-line synopsis and extracting its structural elements. It extends the RegexParsers trait to leverage regular-expression-based parsing mechanisms.
SynopsisParser is responsible for parsing a command-line synopsis and extracting its structural elements. It extends the RegexParsers trait to leverage regular-expression-based parsing mechanisms.
Attributes
- Supertypes
-
trait RegexParserstrait Parsersclass Objecttrait Matchableclass Any
Attributes
- Supertypes
-
trait Producttrait Equalsclass ArgsExceptionclass Exceptionclass Throwabletrait Serializableclass Objecttrait Matchableclass AnyShow all
This represents an Option Value in the parlance of POSIX.