Attributes
- Companion
- object
- Graph
-
- Supertypes
-
trait Serializabletrait Producttrait Equalsclass Objecttrait Matchableclass AnyShow all
Members list
Value members
Concrete methods
Method to concatenate this Args[X] with xq.
Method to concatenate this Args[X] with xq.
Value parameters
- xq
-
an Args[X].
Attributes
- Returns
-
a new Args[X].
Method to prepend an Arg[X] to this Args[X].
Method to prepend an Arg[X] to this Args[X].
Value parameters
- xa
-
the Arg[X] to be prepended.
Attributes
- Returns
-
a new Args[X].
Method to append an Arg[X] to this Args[X].
Method to append an Arg[X] to this Args[X].
Value parameters
- xa
-
the Arg[X] to be appended.
Attributes
- Returns
-
a new Args[X].
Convert this Args[X] to an Args[Y]. In practice, this method invokes map with the function deriveFrom invoked on the Derivable[Y] evidence.
Convert this Args[X] to an Args[Y]. In practice, this method invokes map with the function deriveFrom invoked on the Derivable[Y] evidence.
Type parameters
- Y
-
the underlying type of the result, such that there is evidence of a Derivable[Y] provided implicitly.
Attributes
- Returns
-
an Args[Y].
Attributes
- Definition Classes
-
IterableOps -> IterableOnceOps
Attributes
- Definition Classes
-
IterableOps -> IterableOnceOps
Attributes
- Definition Classes
-
IterableOnceOps
Apply the given function f to each Arg of this Args
Apply the given function f to each Arg of this Args
Type parameters
- Y
-
the result type of the function f
Value parameters
- f
-
a function of type X => Args[Y]
Attributes
- Returns
-
an Args[Y] object
Method to get an Arg whose name matches the given string.
Method to get an Arg whose name matches the given string.
Value parameters
- w
-
the string to match
Attributes
- Returns
-
Some(arg) if the name matches, else None
Get the arg value where the name matches the given string and where the resulting type is Y
Get the arg value where the name matches the given string and where the resulting type is Y
Value parameters
- w
-
the string to match
Attributes
- Returns
-
an option value of Y (None if there is no value).
Get the arg value where the name matches the given string and where the resulting type is Y
Get the arg value where the name matches the given string and where the resulting type is Y
Type parameters
- Y
-
the result type
Value parameters
- w
-
the string to match
Attributes
- Returns
-
an option value of Y (None if toY yields a Failure)
Get the arg value where the name matches the given string and where the resulting type is Y
Get the arg value where the name matches the given string and where the resulting type is Y
Value parameters
- w
-
the string to match
Attributes
- Returns
-
an option value of Y (None if there is no value).
Attributes
- Definition Classes
-
IterableOps
Method to determine if the argument identified by w is defined.
Method to determine if the argument identified by w is defined.
Value parameters
- w
-
the name of an argument (flag).
Attributes
- Returns
-
true if the argument is found by getArg
Attributes
- Definition Classes
-
IterableOnceOps
Attributes
- Definition Classes
-
IterableOps
Apply the given function f to each Arg of this Args
Apply the given function f to each Arg of this Args
Type parameters
- Y
-
the result type of the function f
Value parameters
- f
-
a function of type Arg[X] => Arg[Y]
Attributes
- Returns
-
an Args[Y] object
Apply the given map(f) to each Arg of this Args
Apply the given map(f) to each Arg of this Args
Type parameters
- Y
-
the result type of the function f
Value parameters
- f
-
a function of type X => Y
Attributes
- Returns
-
an Args[Y] object
Apply the given function f, using mapMap, to each Arg of this Args.
Apply the given function f, using mapMap, to each Arg of this Args.
Type parameters
- Y
-
the result type of the function f
Value parameters
- f
-
a function of type X => Option[Y]
Attributes
- Returns
-
an Args[Y] object
Method to process one Arg and return the remainder of the arguments as an Args.
Method to process one Arg and return the remainder of the arguments as an Args.
Value parameters
- f
-
a partially-defined function which can process the arg.
Attributes
- Returns
-
a Success of the remainder if f is defined for the head Arg; a Failure(NoMatchException) if f is not defined for the head Arg; a Failure(EmptyArgsException) if this Args is empty.
Method to process one Arg and return the remainder of the arguments as an Args. In this form of the method, a failure to match by function f (including an empty Args) will result in the default value being returned, rather than a failure.
Method to process one Arg and return the remainder of the arguments as an Args. In this form of the method, a failure to match by function f (including an empty Args) will result in the default value being returned, rather than a failure.
Value parameters
- default
-
a call-by-name value which will be returned in the event that matchAndShift does not succeed.
- f
-
a partially-defined function which can process the arg.
Attributes
- Returns
-
if f is defined for the Arg, then return the remainder; otherwise return the result of invoking default.
Get the operands (positional arguments) as a map of String->X pairs. This is achieved by matching up the names of operands from the synopsis (given) with the operands.
Get the operands (positional arguments) as a map of String->X pairs. This is achieved by matching up the names of operands from the synopsis (given) with the operands.
Value parameters
- s
-
the synopsis from which we will derive the operand names.
Attributes
- Returns
-
a map of String->X pairs.
Process this Args according to the map fm of String->function.
Process this Args according to the map fm of String->function.
Value parameters
- fm
-
a Map of String->function where function is of type Option[X]=>Unit
Attributes
- Returns
-
a Try[Seq[X] resulting from iteration through each Arg and processing it.
Attributes
- Definition Classes
-
IterableOnceOps
Returns a string representation of the object.
Returns a string representation of the object.
The default representation is platform dependent.
Attributes
- Returns
-
a string representation of the object.
- Definition Classes
-
Iterable -> Any
Method to validate this Args according to the POSIX-style synopsis w, expressed as a String.
Method to validate this Args according to the POSIX-style synopsis w, expressed as a String.
Value parameters
- w
-
the synopsis
Attributes
- Returns
-
this Args, assuming that all is OK
Method to validate this Args according to the (optional) synopsis given as sy.
Method to validate this Args according to the (optional) synopsis given as sy.
CONSIDER using lift CONSIDER using map/recover on sy
Value parameters
- sy
-
the optional Synopsis, as produced by SynopsisParser.parseOptionalSynopsis.
Attributes
- Returns
-
this, wrapped in Success, provided that no synopsis was given, or the synopsis was given and parsed successfully and the result of calling validate(Synopsis) is true. If a synopsis string was given but could not be parsed (a Failure other than the NoSuchElementException used by parseOptionalSynopsis to signal "no synopsis given"), that Failure is propagated rather than being silently treated as "nothing to validate".
Inherited methods
Attributes
- Inherited from:
- IterableOps
Attributes
- Inherited from:
- IterableOnceOps
Attributes
- Inherited from:
- IterableOnceOps
Attributes
- Inherited from:
- IterableOnceOps
Attributes
- Inherited from:
- IterableOnceOps
Attributes
- Inherited from:
- IterableOps
Attributes
- Inherited from:
- IterableOnceOps
Attributes
- Inherited from:
- IterableOnceOps
Attributes
- Inherited from:
- IterableOnceOps
Attributes
- Inherited from:
- IterableOnceOps
Attributes
- Definition Classes
-
IterableFactoryDefaults -> IterableOps
- Inherited from:
- IterableFactoryDefaults
Attributes
- Inherited from:
- IterableOps
Attributes
- Inherited from:
- IterableFactoryDefaults
Attributes
- Inherited from:
- IterableOps
Attributes
- Inherited from:
- IterableOps
Attributes
- Definition Classes
-
IterableOps -> IterableOnceOps
- Inherited from:
- IterableOps
Attributes
- Inherited from:
- Iterable
Attributes
- Inherited from:
- IterableOnce
Attributes
- Inherited from:
- Iterable
Attributes
- Inherited from:
- IterableOnceOps
Attributes
- Inherited from:
- IterableOnceOps
Attributes
- Inherited from:
- IterableOnceOps
Attributes
- Inherited from:
- IterableOnceOps
Attributes
- Inherited from:
- IterableOnceOps
Attributes
- Inherited from:
- IterableOnceOps
Attributes
- Inherited from:
- IterableOnceOps
Attributes
- Inherited from:
- IterableOnceOps
Attributes
- Inherited from:
- IterableOnceOps
Attributes
- Inherited from:
- IterableFactoryDefaults
Attributes
- Inherited from:
- IterableOnceOps
Attributes
- Inherited from:
- IterableOps
Attributes
- Inherited from:
- IterableOps
Attributes
- Inherited from:
- Product
Attributes
- Inherited from:
- Product
Attributes
- Inherited from:
- IterableOnceOps
Attributes
- Inherited from:
- IterableOnceOps
Attributes
- Inherited from:
- IterableOnceOps
Attributes
- Inherited from:
- IterableOnceOps
Attributes
- Inherited from:
- IterableOnceOps
Attributes
- Inherited from:
- IterableOps
Attributes
- Inherited from:
- IterableOps
Attributes
- Inherited from:
- IterableOps
Attributes
- Inherited from:
- IterableOps
Attributes
- Inherited from:
- IterableOps
Attributes
- Definition Classes
-
IterableOps -> IterableOnceOps
- Inherited from:
- IterableOps
Attributes
- Inherited from:
- IterableOnce
Attributes
- Definition Classes
-
IterableOps -> IterableOnceOps
- Inherited from:
- IterableOps
Attributes
- Inherited from:
- IterableOnceOps
Attributes
- Inherited from:
- IterableOnceOps
Attributes
- Inherited from:
- IterableOps
Attributes
- Inherited from:
- IterableOps
Attributes
- Inherited from:
- IterableOps
Attributes
- Inherited from:
- IterableOps
Attributes
- Inherited from:
- IterableOps
Attributes
- Inherited from:
- IterableOps
Deprecated and Inherited methods
Attributes
- Deprecated
-
[Since version 2.13.0]Use ++ instead of ++: for collections of type Iterable - Inherited from:
- IterableOps
Attributes
- Deprecated
-
[Since version 2.13.0]Use foldLeft instead of /: - Inherited from:
- IterableOnceOps
Attributes
- Deprecated
-
[Since version 2.13.0]Use foldRight instead of :\\ - Inherited from:
- IterableOnceOps
Attributes
- Deprecated
-
[Since version 2.13.0]For sequential collections, prefer `foldLeft(z)(seqop)`. For parallel collections, use `ParIterableLike#aggregate`. - Inherited from:
- IterableOnceOps
Attributes
- Deprecated
-
[Since version 2.13.0]Use iterableFactory instead - Inherited from:
- IterableOps
Attributes
- Deprecated
-
[Since version 2.13.0]Use `dest ++= coll` instead - Inherited from:
- IterableOnceOps
Attributes
- Deprecated
-
[Since version 2.13.0]Check .knownSize instead of .hasDefiniteSize for more actionable information (see scaladoc for details) - Inherited from:
- IterableOnceOps
Attributes
- Deprecated
-
[Since version 2.13.0]Use coll instead of repr in a collection implementation, use the collection value itself from the outside - Inherited from:
- IterableOps
Attributes
- Deprecated
-
[Since version 2.13.0]Iterable.seq always returns the iterable itself - Inherited from:
- Iterable
Attributes
- Deprecated
-
[Since version 2.13.7]toIterable is internal and will be made protected; its name is similar to `toList` or `toSeq`, but it doesn\'t copy non-immutable collections - Inherited from:
- Iterable
Attributes
- Deprecated
-
[Since version 2.13.0]Use .iterator instead of .toIterator - Inherited from:
- IterableOnceOps
Attributes
- Deprecated
-
[Since version 2.13.0]Use .to(LazyList) instead of .toStream - Inherited from:
- IterableOnceOps
Attributes
- Deprecated
-
[Since version 2.13.0]toTraversable is internal and will be made protected; its name is similar to `toList` or `toSeq`, but it doesn\'t copy non-immutable collections - Inherited from:
- IterableOps
Concrete fields
Get the operands or positional arguments (i.e. args without names) as a sequence of X values.
Get the operands or positional arguments (i.e. args without names) as a sequence of X values.
Attributes
- Returns
-
a sequence of X values.
Get the options (i.e. args with names) as map of names to (optional) values
Get the options (i.e. args with names) as map of names to (optional) values
Attributes
- Returns
-
the options as a map