com.phasmidsoftware.args.Derivable
See theDerivable companion trait
object Derivable
Provides default given instances of the Derivable type class for specific types. Each instance defines a mechanism to derive a value of type T from an input value of type X.
Contains given instances for the following derivations:
- Boolean from String
- Int from String
- Double from String
- java.io.File from String
- java.net.URL from String
Attributes
Members list
Type members
Classlikes
object DerivableStringBoolean extends Derivable[Boolean]
Attributes
- Supertypes
- Self type
object DerivableStringDouble extends Derivable[Double]
Attributes
- Supertypes
- Self type
object DerivableStringFile extends Derivable[File]
Attributes
- Supertypes
- Self type
-
DerivableStringFile.type
object DerivableStringInt extends Derivable[Int]
Attributes
- Supertypes
- Self type
-
DerivableStringInt.type
object DerivableStringURL extends Derivable[URL]
Attributes
- Supertypes
- Self type
-
DerivableStringURL.type
Givens
Givens
In this article