Element
com.phasmidsoftware.args.Element
This represents an element in the synopsis for a command line
Attributes
- Graph
-
- Supertypes
- Known subtypes
Members list
Value members
Abstract methods
Method to yield the value (name) of this Element
Method to yield the value (name) of this Element
Attributes
- Returns
-
the value/name
Concrete methods
Method to yield an optional String according as whether this Element is an operand.
Method to yield an optional String according as whether this Element is an operand.
Attributes
- Returns
-
optionally the value of this Operand element (includes optional elements); None if this Element is not an operand.
Method to compare this Element with that Element.
Method to compare this Element with that Element.
Value parameters
- that
-
the comparand.
Attributes
- Returns
-
the result of invoking value compare that.value
Method to determine if this Element is optional.
Method to determine if this Element is optional.
Attributes
- Returns
-
true if this Element is optional.
Inherited methods
In this article