Flag
This represents an "Option" in the parlance of POSIX command line interpretation (but formerly these options were known as flags)
Value parameters
- value
-
the (single-character) String representing the option (flag)
Attributes
- Graph
-
- Supertypes
Members list
Value members
Inherited methods
Method to yield an optional String according as whether this Element is an operand.
Method to yield an optional String according as whether this Element is an operand.
Attributes
- Returns
-
optionally the value of this Operand element (includes optional elements); None if this Element is not an operand.
- Inherited from:
- Element
Method to compare this Element with that Element.
Method to compare this Element with that Element.
Value parameters
- that
-
the comparand.
Attributes
- Returns
-
the result of invoking value compare that.value
- Inherited from:
- Element
Method to determine if this Element is optional.
Method to determine if this Element is optional.
Attributes
- Returns
-
true if this Element is optional.
- Inherited from:
- Element
Attributes
- Inherited from:
- Product
Attributes
- Inherited from:
- Product