com.phasmidsoftware.examples
package com.phasmidsoftware.examples
Members list
Type members
Classlikes
object ExampleInt
In this example, we convert all of the arguments into Ints.
In this example, we convert all of the arguments into Ints.
Attributes
- Supertypes
-
class Objecttrait Matchableclass Any
- Self type
-
ExampleInt.type
In this article