com.phasmidsoftware.util
Members list
Type members
Classlikes
This is the Kleenean case class which extends Maybe
This trait is to support Kleenean algebra, potentially in a disjunctive or conjunctive expression. The truth-tables for Kleenean logic can be found here: See https://en.wikipedia.org/wiki/Three-valued_logic#Logics Or you can look at KleeneanSpec to see what the rules are.
This trait is to support Kleenean algebra, potentially in a disjunctive or conjunctive expression. The truth-tables for Kleenean logic can be found here: See https://en.wikipedia.org/wiki/Three-valued_logic#Logics Or you can look at KleeneanSpec to see what the rules are.
The original source and specification for Kleenean is in the LaScala project on github at https://github.com/rchillyard/LaScala
Attributes
- Companion
- object
- Supertypes
-
trait () => Option[Boolean]class Objecttrait Matchableclass Any
- Known subtypes
Attributes
- Supertypes
-
class Objecttrait Matchableclass Any
- Self type
-
MonadOps.type
This case object is the None version of Maybe. It is used for the bookends of a dis/conjunctive expression of Maybes. But be careful, you need to understand the rules of Kleenean logic with regard to None combining with true or false.
This case object is the None version of Maybe. It is used for the bookends of a dis/conjunctive expression of Maybes. But be careful, you need to understand the rules of Kleenean logic with regard to None combining with true or false.
Attributes
- Supertypes
- Self type
-
^^.type