This is the Kleenean case class which extends Maybe
Value parameters
- value
-
the Option[Boolean] value
Attributes
Members list
Value members
Concrete methods
Inherited methods
Right-associative conjunctive operator with an Option[Boolean]
Right-associative conjunctive operator with an Option[Boolean]
Value parameters
- x
-
other Maybe value
Attributes
- Returns
-
a Maybe value with is the Kleenean logical AND of this and x
- Inherited from:
- Maybe
Right-associative conjunctive operator with a Boolean
Right-associative conjunctive operator with a Boolean
Value parameters
- b
-
other Maybe value
Attributes
- Returns
-
a Maybe value with is the Kleenean logical AND of this and b
- Inherited from:
- Maybe
Left-associative conjunctive operator with a Boolean
Left-associative conjunctive operator with a Boolean
Value parameters
- b
-
other Boolean value
Attributes
- Returns
-
a Maybe value with is the Kleenean logical AND of this and b
- Inherited from:
- Maybe
Left-associative conjunctive operator with another Maybe
Left-associative conjunctive operator with another Maybe
Value parameters
- m
-
other Maybe value
Attributes
- Returns
-
a Maybe value with is the Kleenean logical AND of this and m
- Inherited from:
- Maybe
Left-associative disjunctive operator with a Boolean
Left-associative disjunctive operator with a Boolean
Value parameters
- b
-
other Maybe value
Attributes
- Returns
-
a Maybe value with is the Kleenean logical OR of this and b
- Inherited from:
- Maybe
Left-associative disjunctive operator with another Maybe
Left-associative disjunctive operator with another Maybe
Value parameters
- m
-
other Maybe value
Attributes
- Returns
-
a Maybe value with is the Kleenean logical OR of this and m
- Inherited from:
- Maybe
Method to deny (invert, negate, ...) this Maybe
Method to deny (invert, negate, ...) this Maybe
TEST this method
Attributes
- Returns
-
Some(!x) if exists, else return None
- Inherited from:
- Maybe
Attributes
- Inherited from:
- Product
Attributes
- Inherited from:
- Product
Method to convert this Maybe into a Boolean
Method to convert this Maybe into a Boolean
Value parameters
- default
-
the value to use if this is None
Attributes
- Returns
-
a Boolean corresponding to either the existing Boolean or else the given default.
- Inherited from:
- Maybe
Method to convert this Maybe into an integer corresponding to the return value of compareTo
Method to convert this Maybe into an integer corresponding to the return value of compareTo
TEST this method
Attributes
- Returns
-
either 1 (true), 0 (maybe), or -1 (false)
- Inherited from:
- Maybe
Right-associative disjunctive operator with a Boolean
Right-associative disjunctive operator with a Boolean
Value parameters
- b
-
other Maybe value
Attributes
- Returns
-
a Maybe value with is the Kleenean logical OR of this and b
- Inherited from:
- Maybe
Right-associative disjunctive operator with an Option[Boolean]
Right-associative disjunctive operator with an Option[Boolean]
Value parameters
- x
-
other Maybe value
Attributes
- Returns
-
a Maybe value with is the Kleenean logical OR of this and x
- Inherited from:
- Maybe