MonadOps
com.phasmidsoftware.util.MonadOps
object MonadOps
Attributes
- Graph
-
- Supertypes
-
class Objecttrait Matchableclass Any
- Self type
-
MonadOps.type
Members list
Value members
Concrete methods
method to map a pair of Option values (of same underlying type) into an Option value of another type (which could be the same of course)
method to map a pair of Option values (of same underlying type) into an Option value of another type (which could be the same of course)
Type parameters
- R
-
the result type
- T1
-
the underlying type of the first parameter
Value parameters
- f
-
function which takes a T1 and a T2 parameter and yields a R result
- t1o
-
a Option[T1] value
- t2o
-
a Option[T2] value
Attributes
- Returns
-
a Option[U]
In this article